compute_drb_result

Function compute_drb_result 

pub async fn compute_drb_result(
    drb_input: DrbInput,
    store_drb_progress: StoreDrbProgressFn,
    load_drb_progress: LoadDrbProgressFn,
    cancel: CancellationToken,
) -> Option<DrbResult>
Compute the DRB result for the leader rotation.

This is to be started two epochs in advance and spawned in a non-blocking thread. Returns None if the computation was cancelled via cancel.

Arguments

  • drb_seed_input - Serialized QC signature.
  • cancel - Token that stops the hash loop when fired.